==> audacious-plugins_3.5.orig.tar.bz2: audacious-plugins-3.5/src/psf/peops2/spu.h <==
/***************************************************************************
                            spu.h  -  description
                             -------------------
    begin                : Wed May 15 2002
    copyright            : (C) 2002 by Pete Bernert
    email                : BlackDove@addcom.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version. See also the license.txt file for *
 *   additional informations.                                              *
 *                                                                         *
 ***************************************************************************/

//*************************************************************************//
// History of changes:
//
// 2004/04/04 - Pete
// - changed plugin to emulate PS2 spu
//
// 2002/05/15 - Pete
// - generic cleanup for the Peops release
//
//*************************************************************************//


void SetupTimer(void);
void RemoveTimer(void);
EXPORT_GCC void CALLBACK SPU2playADPCMchannel(xa_decode_t *xap);

EXPORT_GCC long CALLBACK SPU2init(void);
EXPORT_GCC long CALLBACK SPU2open(void *pDsp);
EXPORT_GCC void CALLBACK SPU2async(unsigned long cycle);
EXPORT_GCC void CALLBACK SPU2close(void);
EXPORT_GCC int  CALLBACK psf2_seek(u32 t);

==> audacious-plugins_3.6.2.orig.tar.bz2: audacious-plugins-3.6.2/src/psf/peops2/spu.h <==
/***************************************************************************
                            spu.h  -  description
                             -------------------
    begin                : Wed May 15 2002
    copyright            : (C) 2002 by Pete Bernert
    email                : BlackDove@addcom.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version. See also the license.txt file for *
 *   additional informations.                                              *
 *                                                                         *
 ***************************************************************************/

//*************************************************************************//
// History of changes:
//
// 2004/04/04 - Pete
// - changed plugin to emulate PS2 spu
//
// 2002/05/15 - Pete
// - generic cleanup for the Peops release
//
//*************************************************************************//


void SetupTimer(void);
void RemoveTimer(void);
EXPORT_GCC void CALLBACK SPU2playADPCMchannel(xa_decode_t *xap);

EXPORT_GCC long CALLBACK SPU2init(void);
EXPORT_GCC long CALLBACK SPU2open(void *pDsp);
EXPORT_GCC void CALLBACK SPU2async(void (*update)(const void *, int));
EXPORT_GCC void CALLBACK SPU2close(void);
EXPORT_GCC int  CALLBACK psf2_seek(u32 t);
